<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_BA">
<context>
    <name>DecoderFFmpegFactory</name>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="135"/>
        <source>FFmpeg Plugin</source>
        <translation>ФФмпег прикључак</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="137"/>
        <source>FFmpeg Formats</source>
        <translation>ФФмпег формати</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="310"/>
        <source>About FFmpeg Audio Plugin</source>
        <translation>О ФФмпег прикључку</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="311"/>
        <source>Qmmp FFmpeg Audio Plugin</source>
        <translation>Кумп ФФмпег прикључак</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="312"/>
        <source>Compiled against:</source>
        <translation>Компилован на:</translation>
    </message>
    <message>
        <location filename="../decoderffmpegfactory.cpp" line="325"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>FFmpeg Plugin Settings</source>
        <translation>Поставке ФФмпег прикључка</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="55"/>
        <source>Formats</source>
        <translation>Формати</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Windows Media Audio</source>
        <translation>Виндоуз Медија Аудио</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="68"/>
        <source>Monkey&apos;s Audio (APE)</source>
        <translation>Манки Аудио (APE)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="75"/>
        <source>True Audio</source>
        <translation>Тру Аудио</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="82"/>
        <source>ADTS AAC</source>
        <translation>ADTS AAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="89"/>
        <source>MP3 (MPEG audio layer 3)</source>
        <translation>MP3 (МПЕГ аудио лејер 3)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="96"/>
        <source>MPEG-4 AAC/ALAC</source>
        <translation>MPEG-4 AAC/ALAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>RealAudio 1.0/2.0</source>
        <translation>Реал Аудио 1.0/2.0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="110"/>
        <source>Shorten</source>
        <translation>Шортен</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="117"/>
        <source>AC3/EAC</source>
        <translation>AC3/EAC</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="124"/>
        <source>DTS/DTS-Core</source>
        <translation>DTS/DTS-Core</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="131"/>
        <source>Matroska Audio (Dolby TrueHD Lossless)</source>
        <translation>Матрошка Аудио (Dolby TrueHD Lossless)</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="138"/>
        <source>VQF</source>
        <translation>VQF</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="145"/>
        <source>Tom&apos;s lossless Audio Kompressor (TAK)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="152"/>
        <source>Direct Stream Digital (DSD)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
